==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SourceRevisionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceRevisionBuilder extends io.fabric8.openshift.api.model.SourceRevisionFluentImpl<io.fabric8.openshift.api.model.SourceRevisionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceRevision,io.fabric8.openshift.api.model.SourceRevisionBuilder>{
  public SourceRevisionBuilder() {
    this(false);
  }
  public SourceRevisionBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceRevision(), validationEnabled);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceRevision(), validationEnabled);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,io.fabric8.openshift.api.model.SourceRevision instance) {
    this(fluent, instance, false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,io.fabric8.openshift.api.model.SourceRevision instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGit(instance.getGit()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevision instance) {
    this(instance,false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevision instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGit(instance.getGit()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceRevision build() {
    SourceRevision buildable = new SourceRevision(fluent.getGit(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceRevisionBuilder that = (SourceRevisionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/SourceRevisionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceRevisionBuilder extends io.fabric8.openshift.api.model.SourceRevisionFluentImpl<io.fabric8.openshift.api.model.SourceRevisionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceRevision,io.fabric8.openshift.api.model.SourceRevisionBuilder>{
  public SourceRevisionBuilder() {
    this(false);
  }
  public SourceRevisionBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceRevision(), validationEnabled);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceRevision(), validationEnabled);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,io.fabric8.openshift.api.model.SourceRevision instance) {
    this(fluent, instance, false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent,io.fabric8.openshift.api.model.SourceRevision instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGit(instance.getGit()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevision instance) {
    this(instance,false);
  }
  public SourceRevisionBuilder(io.fabric8.openshift.api.model.SourceRevision instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGit(instance.getGit()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceRevisionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceRevision build() {
    SourceRevision buildable = new SourceRevision(fluent.getGit(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceRevisionBuilder that = (SourceRevisionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
